==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/content/common/quota_messages.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Multiply-included message file, hence no include guard.

#include "base/basictypes.h"
#include "ipc/ipc_message_macros.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebStorageQuotaError.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebStorageQuotaType.h"

#define IPC_MESSAGE_START QuotaMsgStart

IPC_ENUM_TRAITS(WebKit::WebStorageQuotaType)
IPC_ENUM_TRAITS(WebKit::WebStorageQuotaError)

// Quota messages sent from the browser to the child process.

IPC_MESSAGE_CONTROL2(QuotaMsg_DidGrantStorageQuota,
                     int /* request_id */,
                     int64 /* granted_quota */)

IPC_MESSAGE_CONTROL3(QuotaMsg_DidQueryStorageUsageAndQuota,
                     int /* request_id */,
                     int64 /* current_usage */,
                     int64 /* current_quota */)

IPC_MESSAGE_CONTROL2(QuotaMsg_DidFail,
                     int /* request_id */,
                     WebKit::WebStorageQuotaError /* error */)

// Quota messages sent from the child process to the browser.

IPC_MESSAGE_CONTROL3(QuotaHostMsg_QueryStorageUsageAndQuota,
                     int /* request_id */,
                     GURL /* origin_url */,
                     WebKit::WebStorageQuotaType /* type */)

IPC_MESSAGE_CONTROL5(QuotaHostMsg_RequestStorageQuota,
                     int /* render_view_id */,
                     int /* request_id */,
                     GURL /* origin_url */,
                     WebKit::WebStorageQuotaType /* type */,
                     int64 /* requested_size */)

==> chromium-browser_14.0.835.163~r101024.orig.tar.bz2: chromium-14.0.835.163~r101024/src/content/common/quota_messages.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Multiply-included message file, hence no include guard.

#include "base/basictypes.h"
#include "ipc/ipc_message_macros.h"
#include "webkit/quota/quota_types.h"

#define IPC_MESSAGE_START QuotaMsgStart

IPC_ENUM_TRAITS(quota::StorageType)
IPC_ENUM_TRAITS(quota::QuotaStatusCode)

// Quota messages sent from the browser to the child process.

IPC_MESSAGE_CONTROL2(QuotaMsg_DidGrantStorageQuota,
                     int /* request_id */,
                     int64 /* granted_quota */)

IPC_MESSAGE_CONTROL3(QuotaMsg_DidQueryStorageUsageAndQuota,
                     int /* request_id */,
                     int64 /* current_usage */,
                     int64 /* current_quota */)

IPC_MESSAGE_CONTROL2(QuotaMsg_DidFail,
                     int /* request_id */,
                     quota::QuotaStatusCode /* error */)

// Quota messages sent from the child process to the browser.

IPC_MESSAGE_CONTROL3(QuotaHostMsg_QueryStorageUsageAndQuota,
                     int /* request_id */,
                     GURL /* origin_url */,
                     quota::StorageType /* type */)

IPC_MESSAGE_CONTROL5(QuotaHostMsg_RequestStorageQuota,
                     int /* render_view_id */,
                     int /* request_id */,
                     GURL /* origin_url */,
                     quota::StorageType /* type */,
                     int64 /* requested_size */)
